@@ -3,22 +3,18 @@ package Acme::CPANModules::MockModules;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-04-01'; # DATE
+our $DATE = '2025-01-01'; # DATE
 our $DIST = 'Acme-CPANModules-MockModules'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => 'List of modules that mock other modules',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 Not to be confused with modules which you can use to do mock testing.
 
-_
+MARKDOWN
     entries => [
-        {
-            module => 'Log::Any::IfLOG',
-            mocked_module => 'Log::Any',
-        },
         {
             module => 'Locale::TextDomain::IfEnv',
             mocked_module => 'Locale::TextDomain',
@@ -45,7 +41,7 @@ Acme::CPANModules::MockModules - List of modules that mock other modules
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::MockModules (from Perl distribution Acme-CPANModules-MockModules), released on 2022-04-01.
+This document describes version 0.003 of Acme::CPANModules::MockModules (from Perl distribution Acme-CPANModules-MockModules), released on 2025-01-01.
 
 =head1 DESCRIPTION
 
@@ -55,15 +51,11 @@ Not to be confused with modules which you can use to do mock testing.
 
 =over
 
-=item * L<Log::Any::IfLOG> - Load Log::Any only if "logging is enabled"
+=item L<Locale::TextDomain::IfEnv>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Locale::TextDomain::IfEnv> - Enable translation only when environment variable flag is true
-
-Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
-
-=item * L<Locale::TextDomain::UTF8::IfEnv> - Enable translation + UTF-8 encoding only when environment variable flag is true
+=item L<Locale::TextDomain::UTF8::IfEnv>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
@@ -135,13 +127,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
